@@ -369,8 +369,8 @@ class InlineProcessor(Treeprocessor):
                     lst = self.__processPlaceholders(
                         self.__handleInline(text), child
                     )
-                    for l in lst:
-                        self.parent_map[l[0]] = child
+                    for item in lst:
+                        self.parent_map[item[0]] = child
                     stack += lst
                     insertQueue.append((child, lst))
                     self.ancestors.pop()
